iosInfoPlistPath property

String iosInfoPlistPath
final

Tells verman where to look for your ios info.plist if left undefined then value will be defaulted to '~/ios/runner/info.plist'

Implementation

final String iosInfoPlistPath;