iosInfoPlistPath property
Tells verman where to look for your ios info.plist if left undefined then value will be defaulted to '~/ios/runner/info.plist'
Implementation
final String iosInfoPlistPath;
Tells verman where to look for your ios info.plist if left undefined then value will be defaulted to '~/ios/runner/info.plist'
final String iosInfoPlistPath;